<!doctype html>
<html lang="zh-CN">
{% include 'head.html' %}
<body>
    <div class="container mt-5">
        <div class="alert alert-warning text-center" role="alert">
            <h4 class="alert-heading">提示</h4>
            <p>{{ message }}</p>
        </div>
    </div>
</body>
</html>