<nav class="q-navbar navbar navbar-expand-lg navbar-light bg-light p-4" role="navigation">
    <div class="container">
        <a class="navbar-brand d-flex align-items-center" href="/">
            <img class="me-2" src="{{ url_for('static', filename='logo.jpg') }}" width="28" height="28" alt="">
            <span style="font-weight: bold;">量化投资助手</span>
        </a>

        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarBasicExample" aria-controls="navbarBasicExample" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>

        <div class="collapse navbar-collapse" id="navbarBasicExample">
            <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                <li class="nav-item">
                    <a class="nav-link" href="#">数据</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#">股池</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#">回测</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#">实盘</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="/setting">设置</a>
                </li>
            </ul>
        </div>
    </div>
</nav>
