{% extends 'base.html' %}

{% block content %}
<style>
    html,
    body {
        height: 100%;
        margin: 0;
    }

    .center-container {
        display: flex;
        justify-content: center;
        align-items: center;
        height: 100%;
    }
</style>
<div class="center-container">
    <div class="container">
        <div class="row">
            <h1 class="bd-title">量化投资助手</h1>
        </div>
        <div class="row">  
            <input type="date">
            <input type="time">     
        </div>
    </div>
</div>

{% endblock %}