<!doctype html>
<html lang="en">
    {% include 'head.html' %}
    <body>
        {% include 'navbar.html' %}
        <!-- Your page content -->
        {% block content %}{% endblock %}
    </body>
</html>