<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>量化投资助手</title>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.min.js" defer></script>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            font-family: "Microsoft YaHei", sans-serif; /* 设置为微软雅黑 */
        }
        .q-navbar .nav-link {
            font-weight: 500; /* 加粗字体 */
            width: 70px;
        }
        .navbar-brand {
            margin-right: 40px;
        }
    </style>
</head>